@@ -16,8 +16,8 @@ from fluxvault.log import log
 class FluxPrimaryAgent:
     """Container to hold parent agent info"""
 
-    name: str = ""
-    port: int | None = None
+    name: str = "fluxagent"
+    port: int = 2080
     address: str | None = None
 
 
